Profils simplifiés
==================

Étant donnés l'étendue et la complexité du SEDA, ainsi que le désir de pouvoir exporté des profils
vers les anciennes version 1.0 et 0.2, une implémentation simplifiée est mise à disposition.

Seul les profils simplifiés pourront être exportés vers les anciennes versions. Ils seront a priori
toujours exportable en SEDA 2 également.